﻿using System;
using System.Collections.Generic;
using System.Drawing.Drawing2D;
using System.IO;
using System.Linq;
using System.Net.Sockets;
using System.Text;
using System.Threading.Tasks;

namespace AirFighter
{
    public class DrawningAirFighter
    {
        public EntityAirFighter? EntityAirFighter { get; private set; }

        private int _pictureWidth;
        
        private int _pictureHeight;
      
        private int _startPosX;
        
        private int _startPosY;
        
        private readonly int _fighterWidth = 195;
       
        private readonly int _fighterHeight = 166;
        
        public bool Init(int speed, double weight, Color bodyColor, Color additionalColor, bool wing, bool rocket, int width, int height)
        {        
            if (width < _pictureWidth || height < _pictureHeight)
            {
                return false;
            }
            _pictureWidth = width;
            _pictureHeight = height;
            EntityAirFighter = new EntityAirFighter();
            EntityAirFighter.Init(speed, weight, bodyColor, additionalColor, wing, rocket);
            return true;
        }      
        public void SetPosition(int x, int y)
        {
            if (x < 0)
            {
                x = 0; 
            }
            else if (x > _pictureWidth - _fighterWidth)
            {
                x = _pictureWidth - _fighterWidth; 
            }
            if (y < 0)
            {
                y = 0; 
            }
            else if (y > _pictureHeight - _fighterHeight)
            {
                y = _pictureHeight - _fighterHeight; 
            }
            _startPosX = x;
            _startPosY = y;
        }       
        public void MoveTransport(DirectionAirFighter direction)
        {
            if (EntityAirFighter == null)
            {
                return;
            }
            switch (direction)
            {
                case DirectionAirFighter.Left:
                    if (_startPosX - EntityAirFighter.Step > 0)
                    {
                        _startPosX -= (int)EntityAirFighter.Step;
                    }
                    else if (_startPosX - EntityAirFighter.Step < 0)
                    {
                        _startPosX = _startPosX - _startPosX + 3;
                    }
                    break;

                case DirectionAirFighter.Up:
                    if (_startPosY - EntityAirFighter.Step > 0)
                    {
                        _startPosY -= (int)EntityAirFighter.Step;
                    }
                    else if (_startPosY - EntityAirFighter.Step < 0)
                    {
                        _startPosY = _startPosY - _startPosY + 0;
                    }
                    break;
                
                case DirectionAirFighter.Right:
                    if (_startPosX + EntityAirFighter.Step + _fighterWidth < _pictureWidth)
                    {
                        _startPosX += (int)EntityAirFighter.Step;
                    }
                    else if (_startPosX + EntityAirFighter.Step + _fighterWidth > _pictureWidth)
                    {
                        _startPosX += _pictureWidth - _startPosX - _fighterWidth;
                    }

                    break;
               
                case DirectionAirFighter.Down:
                    if (_startPosY + EntityAirFighter.Step + _fighterHeight < _pictureHeight)
                    {
                        _startPosY += (int)EntityAirFighter.Step;
                    }
                    else if (_startPosY + EntityAirFighter.Step + _fighterHeight > _pictureHeight)
                    {
                        _startPosY += _pictureHeight - _startPosY - _fighterHeight;
                    }
                    break;
            }
        }
        public void DrawTransport(Graphics g)
        {
            if (EntityAirFighter == null)
            {
                return;
            }
            Pen pen = new(EntityAirFighter.BodyColor, 2);
            Brush brushBlack = new SolidBrush(EntityAirFighter.BodyColor);

            PointF[] front = {
                new(_startPosX + 160, _startPosY + 69),
                new(_startPosX + 195, _startPosY + 83),
                new(_startPosX + 160, _startPosY + 97)
            };

            PointF[] tailTop = {
                new(_startPosX, _startPosY + 30),
                new(_startPosX, _startPosY + 70),
                new(_startPosX + 25, _startPosY + 70),
                new(_startPosX + 25, _startPosY + 55)
            };

            PointF[] tailBottom = {
                new(_startPosX, _startPosY + 96),
                new(_startPosX, _startPosY + 136),
                new(_startPosX + 25, _startPosY + 111),
                new(_startPosX + 25, _startPosY + 96)
            };

            PointF[] wingTop =
            {
                new(_startPosX + 100, _startPosY),
                new(_startPosX + 100, _startPosY + 70),
                new(_startPosX + 75, _startPosY + 70),
                new(_startPosX + 90, _startPosY),
            };
            PointF[] wingBottom =
            {
                new(_startPosX + 100, _startPosY + 96),
                new(_startPosX + 100, _startPosY + 166),
                new(_startPosX + 90, _startPosY + 166),
                new(_startPosX + 75, _startPosY + 96),
            };

            g.DrawPolygon(pen, tailTop);
            g.DrawPolygon(pen, tailBottom);
            g.DrawPolygon(pen, wingTop);
            g.DrawPolygon(pen, wingBottom);
            g.DrawRectangle(pen, _startPosX, _startPosY + 70, 160, 26);
            g.FillPolygon(brushBlack, front);

            Brush additionalBrush = new SolidBrush(EntityAirFighter.AdditionalColor);

            if (EntityAirFighter.Wing)
            {
                PointF[] topDopWing =
                {
                    new(_startPosX + 78, _startPosY + 56),
                    new(_startPosX + 75, _startPosY + 70),
                    new(_startPosX + 55, _startPosY + 50),
                    new(_startPosX + 60, _startPosY + 45),
                };

                PointF[] bottomDopWing =
                {
                    new(_startPosX + 78, _startPosY + 110),
                    new(_startPosX + 75, _startPosY + 96),
                    new(_startPosX + 55, _startPosY + 116),
                    new(_startPosX + 60, _startPosY + 121),
                };

                g.FillPolygon(additionalBrush, topDopWing);
                g.FillPolygon(additionalBrush, bottomDopWing);

            }

            if (EntityAirFighter.Rocket)
            {
                PointF[] topRocket1 =
               {
                    new(_startPosX + 100, _startPosY + 20),
                    new(_startPosX + 100, _startPosY + 30),
                    new(_startPosX + 112, _startPosY + 30),
                    new(_startPosX + 120, _startPosY + 25),
                    new(_startPosX + 112, _startPosY + 20)
                };

                PointF[] topRocket2 =
                {
                    new(_startPosX + 100, _startPosY + 35),
                    new(_startPosX + 100, _startPosY + 45),
                    new(_startPosX + 112, _startPosY + 45),
                    new(_startPosX + 120, _startPosY + 40),
                    new(_startPosX + 112, _startPosY + 35)
                };

                PointF[] bottomRocket1 =
                {
                    new(_startPosX + 100, _startPosY + 146),
                    new(_startPosX + 100, _startPosY + 136),
                    new(_startPosX + 112, _startPosY + 136),
                    new(_startPosX + 120, _startPosY + 141),
                    new(_startPosX + 112, _startPosY + 146)
                };

                PointF[] bottomRocket2 =
                {
                    new(_startPosX + 100, _startPosY + 131),
                    new(_startPosX + 100, _startPosY + 121),
                    new(_startPosX + 112, _startPosY + 121),
                    new(_startPosX + 120, _startPosY + 126),
                    new(_startPosX + 112, _startPosY + 131)
                };

                g.FillPolygon(additionalBrush, topRocket1);
                g.FillPolygon(additionalBrush, topRocket2);
                g.FillPolygon(additionalBrush, bottomRocket1);
                g.FillPolygon(additionalBrush, bottomRocket2);
            }
        }
    }
        
}
       

  
